import QtQuick 1.0
import Qt.labs.presentation 1.0
import QtMobility.location 1.2
import QtMultimediaKit 1.1


Presentation {
    width: 1280
    height: 720

    Rectangle {
        anchors.fill: parent
        gradient: Gradient {
            GradientStop { position: 0.0; color: "lightgrey" }
            GradientStop { position: 1.0; color: "green" }
        }

        Text {
            id: timeText
            text: "Time elapsed"
        }
    }

    Timer {
        interval: 500; running: true; repeat: true
        onTriggered: timeText.text = Date().toTimeString();
    }

    Slide {
        centeredText: "<b>Qt (open) Mobility</b><br>Jaroslav Řezník &lt;jreznik@redhat.com&gt;"
    }

    Slide {
        Column {
            anchors.centerIn: parent
            spacing: 50

            Text {
                font.pixelSize: 40
                text: "CC-BY-SA"
            }
            Image {
                anchors.horizontalCenter: parent.horizontalCenter
                source: "cc-by-sa.png"
            }
        }
    }

    Slide {
        title: "Agenda"

        content: [
            "Přednášková část",
            " Qt v mobilních zařízeních",
            " Qt SDK",
            " Qt Quick",
            " Qt Mobility",
            " Qt v reálných mobilních aplikacích",
            "nebo-li Qt Everywhere a všichni jsme Qt",
            "Workshop",
            " jednoduchá aplikace v Qt Quick"
        ]
    }

    Slide {
        title: "O autorovi"

        content: [
            "Software Engineer v Red Hat Czech Brno",
            " vývojář Fedory",
            "  KDE a Qt",
            "  konfigurační nástroje",
            "spoluzakladatel a místopředseda sdružení Openmobility",
            "člen Fedora Board, Fedora ambassador a člen KDE SIG",
            "a celkově blázen do všeho open a mobilního"
        ]
    }

    Slide {
        title: "Qt v mobilních zařízeních"

        content: [
            "Nokia",
            "Intel"
        ]
    }

    Slide {
        title: "Qt SDK 1.1"

        content: [
            "obsahuje integrované",
            " Qt 4.7",
            " Qt Creator",
            " Qt Mobility",
            " Qt Simulator",
            " Symbian Toolchain",
            " Maemo 5 Toolchain",
            " nástroje pro správu SDK",
            "  update atd."
        ]
    }

    Slide {
        title: "Qt SDK - podporované platformy"

        content: [
            "Symbian",
            " Qt 4.7.x jen v S60 series 5 (Symbian^1, Symbian^3)",
            "Maemo 5",
            "MeeGo",
            "Harmattan",
            " není k dispozici prozatím",
            "Android",
            " neoficiální komunitní port Necessitas"
        ]
    }

    Slide {
        title: "Qt SDK - remote compiler"

        content: [
            "Symbian toolchain není k dispozici pro Linux a Mac OS X",
            "veřejně přístupný remote compiler",
            " s výběrem cílového systému"
        ]
    }

    Slide {
        title: "Qt Quick"

        content: [
            "QML - CSS & JavaScript like programovací jazyk",
            " analogie HTML a CSS",
            "  kde HTML je C++",
            "  QML je CSS (s JS)",
            "Propojení mezi designerem a programátorem"
        ]
    }

    Slide {
        title: "Qt Quick - tlačítko"

        Column {
            spacing: 50

            Row {
                spacing: 5

                Button {
                    id: prvni
                    text: "První"

                    onClicked: druhe.text = "První"
                }

                Button {
                    id: druhe
                    text: "Druhé"

                    onClicked: treti.text = "Druhé"
                }

                Button {
                    id: treti
                    text: "Třetí"

                    onClicked: prvni.text = "Třetí"
                }
            }

            Grid {
                rows: 3
                columns: 3
                spacing: 5

                Repeater {
                    model: 9
                    Button {
                        text: index

                        onClicked: dialNumber.text = dialNumber.text + index
                    }
                }
            }

            Text {
                anchors.horizontalCenter: parent.horizontalCenter
                id: dialNumber
                font.pointSize: 30
            }
        }

        CodeSection {
            text: "
Rectangle {
    id: container
    property alias text: textItem.text
    signal clicked

    width: 100; height: 30; radius: 5

    gradient:  Gradient {
    GradientStop { position: 0.0; color: \"lightgreen\"; }
    GradientStop { position: 1.0; color: \"green\"; }
    }
    Text {
        anchors.centerIn: parent
        color: \"white\"
        id: textItem
    }
    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: container.clicked()
    }
}
            "
        }
    }

    Slide {
        title: "Budoucnost"

        content: [
            "Qt 5 GUI založené na Qt Quick",
            "Qt Components",
            "Qt Scene Graph",
            " OpenGL akcelerace"
        ]
    }

    Slide {
        title: "Qt Components"

        content: [
            "UI komponenty postavené nad Qt Quick",
            " aktuálně ve vývoji",
            "Qt Components",
            " zařízení od Nokie, i desktop",
            "MeeGo Components",
            " Intel"
        ]
    }

    Slide {
        title: "Qt Mobility"

        content: [
            "Sada C++ tříd a QML pluginů využitelných v mobilních zařízeních, např.:",
            " Connectivity (Bluetooth, NFC)",
            " Contacts",
            " Document Gallery",
            " Location",
            " Messaging",
            " Multimedia",
            " Sensors",
            " a další",
            "Ne vše je k dispozici v QML"
        ]
    }

    Slide {
        title: "Qt Mobility - geolokace a mapy"

        content: [
            "Geolokace",
            "Mapy",
            "Landmarks"
        ]

        CodeSection {
            text: "
Map {
    id: map
    plugin : Plugin {name : \"nokia\"}
    zoomLevel: 10

    center: Coordinate {
        latitude: 49.2
        longitude: 16.6333333
    }
}
"
        }
    }

    Slide {
        title: "Qt Mobility - geolokace a mapy"

        Map {
             id: map
             plugin : Plugin {name : "nokia"}
             anchors.fill: parent
             size.width: parent.width
             size.height: parent.height
             zoomLevel: 10

             center: Coordinate {
                 latitude: 49.2
                 longitude: 16.6333333
             }
        }
    }

    Slide {
        title: "Qt Mobility - multimedia"

        content: [
            "audio",
            "video",
            "a práce s kamerou"
        ]

        CodeSection {
            text: "import QtMultimediaKit 1.1\n\nAudio {\n" +
            "\tid: playMusic\n" +
            "\tsource: \"file:/KDE-Sys-Log-In-Short.ogg\"\n" +
            "}\n\n" +

            "Row {\n" +
            "\tanchors.bottom: parent.bottom\n" +
            "\tspacing: 5\n" +

            "\tButton {\n" +
            "\t\ttext: \"Play\"\n" +
            "\t\tonClicked: playMusic.play()\n" +
            "\t}\n" +
            "\tButton {\n" +
            "\t\ttext: \"Stop\"\n" +
            "\t\tonClicked: playMusic.stop()\n" +
            "\t}\n" +
            "}\n"
        }

        Audio {
            id: playMusic
            source: "file:/usr/share/sounds/KDE-Sys-Log-In-Short.ogg"
        }

        Row {
            anchors.bottom: parent.bottom
            spacing: 5

            Button {
                text: "Play"
                onClicked: playMusic.play()
            }
            Button {
                text: "Stop"
                onClicked: playMusic.stop()
            }
        }

    }

    Slide {
        title: "Qt v reálných mobilních aplikacích"

        content: [
            "Maemo",
            " díky komunitní povaze bez problémů",
            "  původně komunitní port",
            "Symbian a OVI Store",
            " omezení na určité verze dle Qt SDK",
            " Smart installer",
            "Ukázka reálných aplikací v QML"
        ]
    }

    Slide {
        centeredText: "Workshop - let's do some code"
    }

    Slide {
        title: "Program Openmobility jako Qt Quick aplikace"

        content: [
            "Jednoduchá aplikace zobrazující program konference",
            " XML z internetu"
        ]
    }

}
